@@ -82,13 +82,14 @@ class Contracts:
         for root, dirs, files in os.walk(folder_path, topdown=False):
             for name in files:
                 path = os.path.join(root, name)
-                if 'output' not in path and 'docx' in path and 'Э' not in path:
+                if ('output' not in path) and ('docx' or 'doc' in path) and ('Э' not in path):
                     try:
                         self.tg.append(''.join(filter(None,regex.search(self.exp, path).groups())))
                         self.all_files.append(path)
                     except:
-                        print('Ŀǰֻ֧֣̩||ŽͶ||㷢|ͨ|||ƽ||ҵ||ͶйܵĲƷᱻԡ')
-
+                        print('Ŀǰֻ֧֣̩||ŽͶ||㷢|ͨ|||ƽ||ҵ||ͶwordĵйܵĲƷᱻԡ')
+                else:
+                    pass
     def get_chapters(self, chapter_names):
         out = {}
         for file_path in self.all_files:
